==> virtualbox-ose_3.2.4-dfsg.orig.tar.gz: virtualbox-ose-3.2.4-dfsg/src/VBox/Runtime/common/string/RTStrNLenEx.cpp <==
/* $Id: RTStrNLenEx.cpp $ */
/** @file
 * IPRT - RTStrNLenEx.
 */

/*
 * Copyright (C) 2008 Oracle Corporation
 *
 * This file is part of VirtualBox Open Source Edition (OSE), as
 * available from http://www.virtualbox.org. This file is free software;
 * you can redistribute it and/or modify it under the terms of the GNU
 * General Public License (GPL) as published by the Free Software
 * Foundation, in version 2 as it comes in the "COPYING" file of the
 * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
 *
 * The contents of this file may alternatively be used under the terms
 * of the Common Development and Distribution License Version 1.0
 * (CDDL) only, as it comes in the "COPYING.CDDL" file of the
 * VirtualBox OSE distribution, in which case the provisions of the
 * CDDL are applicable instead of those of the GPL.
 *
 * You may elect to license modified versions of this file under the
 * terms and conditions of either the GPL or the CDDL or both.
 */

/*******************************************************************************
*   Header Files                                                               *
*******************************************************************************/
#include <iprt/string.h>
#include "internal/iprt.h"


RTDECL(int) RTStrNLenEx(const char *pszString, size_t cchMax, size_t *pcch)
{
    const char *pchEnd = (const char *)memchr(pszString, '\0', cchMax);
    if (!pchEnd)
    {
        *pcch = cchMax;
        return VERR_BUFFER_OVERFLOW;
    }
    *pcch = pchEnd - pszString;
    return VINF_SUCCESS;
}
RT_EXPORT_SYMBOL(RTStrNLenEx);

==> virtualbox-ose_3.2.28-dfsg.orig.tar.gz: virtualbox-ose-3.2.28-dfsg/src/VBox/Runtime/common/string/RTStrNLenEx.cpp <==
/* $Id: RTStrNLenEx.cpp $ */
/** @file
 * IPRT - RTStrNLenEx.
 */

/*
 * Copyright (C) 2008 Oracle Corporation
 *
 * This file is part of VirtualBox Open Source Edition (OSE), as
 * available from http://www.virtualbox.org. This file is free software;
 * you can redistribute it and/or modify it under the terms of the GNU
 * General Public License (GPL) as published by the Free Software
 * Foundation, in version 2 as it comes in the "COPYING" file of the
 * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
 *
 * The contents of this file may alternatively be used under the terms
 * of the Common Development and Distribution License Version 1.0
 * (CDDL) only, as it comes in the "COPYING.CDDL" file of the
 * VirtualBox OSE distribution, in which case the provisions of the
 * CDDL are applicable instead of those of the GPL.
 *
 * You may elect to license modified versions of this file under the
 * terms and conditions of either the GPL or the CDDL or both.
 */

/*******************************************************************************
*   Header Files                                                               *
*******************************************************************************/
#include <iprt/string.h>
#include "internal/iprt.h"


RTDECL(int) RTStrNLenEx(const char *pszString, size_t cchMax, size_t *pcch)
{
    const char *pchEnd = RTStrEnd(pszString, cchMax);
    if (!pchEnd)
    {
        *pcch = cchMax;
        return VERR_BUFFER_OVERFLOW;
    }
    *pcch = pchEnd - pszString;
    return VINF_SUCCESS;
}
RT_EXPORT_SYMBOL(RTStrNLenEx);
